==> prestashop_1.5.0.15.zip: prestashop/translations/it/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF01a2436b8e3782c1f99e6b26adf901b2'] = 'Valore tassa';
$_LANGPDF['PDF023f66b09075fa1cc29e74bed9f5ac40'] = 'Dettaglio tasse';
$_LANGPDF['PDF03ab340b3f99e03cff9e84314ead38c0'] = 'Qtà';
$_LANGPDF['PDF065ab3a28ca4f16f55f103adc7d0226f'] = 'Consegna';
$_LANGPDF['PDF068f80c7519d0528fb08e82137a72131'] = 'Prodotti';
$_LANGPDF['PDF078ac079d154d21533c57bced9fcb10f'] = '(tasse escl.):';
$_LANGPDF['PDF0d8d58008ef5dd7afce337373ef73993'] = 'Data';
$_LANGPDF['PDF104d9898c04874d0fbac36e125fa1369'] = 'Sconto';
$_LANGPDF['PDF1300f86974cafc2d65eb1f082a26bdf1'] = 'Riepilogo';
$_LANGPDF['PDF197101c4a1b1fc503dcd6ebee127aa10'] = 'PU';
$_LANGPDF['PDF19abe6c02a26dcd93020396df8d0721c'] = 'Totale sconti:';
$_LANGPDF['PDF1a22913fb1b16ada25c2637af9d44013'] = 'Prodotto / Riferimento';
$_LANGPDF['PDF20a34c4e30c5bbe1d3f870ac55f0d831'] = 'Aliquota tassa';
$_LANGPDF['PDF22caf639b05c0fa192e81d58c553c89a'] = 'Totale tasse escluse';
$_LANGPDF['PDF28a59051cd90053f87bacd5f1ffbc0b8'] = 'Indirizzo di fatturazione';
$_LANGPDF['PDF29103375229a5c363403ec4afb5c3e8f'] = '(tasse incl.)';
$_LANGPDF['PDF2b56b5ec383be252fe778c4c6066b2fb'] = 'Indirizzo di fatturazione e spedizione';
$_LANGPDF['PDF2f2f0f119a907c6c67a3c6fcde0193ab'] = 'Indirizzo di consegna:';
$_LANGPDF['PDF2fc3a7b3466e28c082f9957b5df63066'] = 'Importo dovuto rimanente';
$_LANGPDF['PDF34bfda153cbe51eef5d4a88cdd7b616d'] = 'Stampa questo documento ed inseriscilo nel pacco da restituire.';
$_LANGPDF['PDF3796bba38e4bc7dbc3ec97d73be42328'] = 'Se le seguenti condizioni non sono rispettate ci riserviamo il diritto di rifiutare il pacchetto e / o rimborso:';
$_LANGPDF['PDF3a6a6d37bea2c7567f8599ea88b47930'] = 'Totale Tasse Escluse';
$_LANGPDF['PDF3a80d6ec5285dd5d3930db30d04e2b9e'] = 'SE: Sconto escluso';
$_LANGPDF['PDF448634536559b1f8aaa975e0aa12b930'] = 'TOTALE DA PAGARE';
$_LANGPDF['PDF5082245495aa792b3d0874088d2b111b'] = 'Totale prodotto';
$_LANGPDF['PDF59aac4eb50a8249cbc9c12240c6a0a14'] = 'Per ulteriore assistenza contatta il nostro servizio clienti:';
$_LANGPDF['PDF5e5f0a863cd129317037e3def37b4097'] = 'Azienda:';
$_LANGPDF['PDF627be65d466c88030f7afcfdaf6d794f'] = '(Sconto escluso)';
$_LANGPDF['PDF63d5049791d9d79d86e9a108b0a999ca'] = 'Riferimento';
$_LANGPDF['PDF66f6e4bbd0a0af1af6b54763871dd280'] = 'Prodotti ordinati:';
$_LANGPDF['PDF6703aa9936582b4381418f7d523370b4'] = 'Aliquota sconto';
$_LANGPDF['PDF67606e3dd25c5effeb991c704b96d19c'] = 'Tutti I prodotti devono essere restituiti nel loro imballo originale senza danni o usura';
$_LANGPDF['PDF699e6bd4690ed3bd5f658052e12aba04'] = 'Valore tassa';
$_LANGPDF['PDF6b9e9f2472786ed1e76005bfc37bc8af'] = 'Sconto ordine';
$_LANGPDF['PDF6c2fbe34c186a6b5725d212ad8cd2432'] = 'Fatture';
$_LANGPDF['PDF6f3455d187a23443796efdcbe044096b'] = 'Nessuna tassa';
$_LANGPDF['PDF7137a85d9b8d9e6d09f47767d2ca31ee'] = 'APE';
$_LANGPDF['PDF716be2c7de31f063369ca297a9928403'] = 'Tasse';
$_LANGPDF['PDF7521172dd37ba56442ea866ac18eb49d'] = 'Prima dello sconto';
$_LANGPDF['PDF752ab8bad7c2e2d894ffa7f2b4f59919'] = 'Numero reso:';
$_LANGPDF['PDF77c48b105700c87484e3008ca52a8e57'] = '(Sconto non incluso)';
$_LANGPDF['PDF7926243ab60a08b15932021bf108c578'] = 'Totale prodotto (Tasse escl.)';
$_LANGPDF['PDF88be9ea838e21273267409d76af3b284'] = 'Abbiamo registrato la vostra richiesta di restituzione.';
$_LANGPDF['PDF8a5a12ba783d8cbb761974430d0a4d6a'] = 'Data ordine:';
$_LANGPDF['PDF8fe77c2601e54f1aaef28cfde997bbad'] = 'Aliquota tasse';
$_LANGPDF['PDF96b0141273eabab320119c467cdcaf17'] = 'Totale';
$_LANGPDF['PDF984a93f9899bf0b0a250ba66f022c630'] = 'Totale prodotto (Tasse incl.)';
$_LANGPDF['PDF9a40e5f45fab9e73d0bc7dad94f6caa3'] = 'Ordine di ritorno';
$_LANGPDF['PDF9e023503a19456d31f0760015d035e36'] = 'Ricorda di inserire questo numero di riferimento reso nel pacco da rendere';
$_LANGPDF['PDFa58b1c9575ab07c5be819243c96d9c0e'] = 'SI: Sconto incluso';
$_LANGPDF['PDFa5e35abc0c9e2d2784d0ef619b36448b'] = 'Costi di spedizione';
$_LANGPDF['PDFa61109b693023aed557445989c517982'] = 'Dopo lo sconto';
$_LANGPDF['PDFabd7ef0bbbdeed3a98c962ba07747ca8'] = 'PRODOTTI DA RENDERE';
$_LANGPDF['PDFb602e0d0c6a72053d0a5be60cb2f8126'] = 'Totale tasse:';
$_LANGPDF['PDFc7711fbc0d8f010e06a306cc63ef5393'] = 'Il pacco deve essere restituito al seguente indirizzo:';
$_LANGPDF['PDFc7d76074f459eaa296d3eb71efc23eba'] = 'Rimborso #';
$_LANGPDF['PDFc8ba77264f6e923f5ee35abf3108ae7c'] = 'Prezzo unitario Tasse Escluse';
$_LANGPDF['PDFced2da7b2baf942c0ffd4b8e45ec0fad'] = 'Costo spedizione';
$_LANGPDF['PDFd04e2c1b67f3ef0d475409516b812e8b'] = 'SIRET';
$_LANGPDF['PDFd36a6948b01d3a75ed99858e2bfea939'] = 'Metodo di pagamento:';
$_LANGPDF['PDFd8b2145d049378e78bd41e65b31213f0'] = 'Numero ordine:';
$_LANGPDF['PDFdcd320d017d7f3c317bc8b234287bc9f'] = 'riferimento';
$_LANGPDF['PDFdd0b8feb4eb6c389c284518f5683017c'] = 'Il tuo pacchetto deve essere restituito entro';
$_LANGPDF['PDFe2f324b87eac820c81e4d4a1105dcddf'] = 'Indirizzo di fatturazione e spedizione';
$_LANGPDF['PDFe36ba4b339b83cbb3c807bd0eb5610bc'] = 'Qtà';
$_LANGPDF['PDFe40007b408ac5f66d2c2e6c54f787c99'] = 'Nessun pagamento';
$_LANGPDF['PDFe7bbf027179f23c92bec649fa6ae78e4'] = 'Esente IVA a seconda della sezione 259B del codice generale delle imposte.';
$_LANGPDF['PDFe92cfa244b5eb9025d07522080468445'] = 'Eco- tassa';
$_LANGPDF['PDFea62a2e28a800c367509773730120a67'] = 'giorni dal ricevimento dell\'ordine.';
$_LANGPDF['PDFea9cf7e47ff33b2be14e6dd07cbcefc6'] = 'Spedizione';
$_LANGPDF['PDFf107f5a9ee4ecea58d0f29ae7959baa8'] = 'Designazione';
$_LANGPDF['PDFf4a232c48df10124ee867767a4e7280e'] = 'Base Tasse Escluse';
$_LANGPDF['PDFf6244b08d5e0715572f9d4631b425eae'] = 'ARTICOLI DA SPEDIRE';
$_LANGPDF['PDFf771e4a4df40bf061607fdb8e3f140dc'] = 'Modulo ordine fornitura';
$_LANGPDF['PDFfa2ce544158555e8f06c69dd9e681832'] = 'Totale Tasse Incluse';
$_LANGPDF['PDFff5db4935fb0fbf583796b50f05e25bc'] = 'Una versione elettronica di questa fattura è disponibile nel tuo account. Per accedervi, accedere al nostro sito utilizzando il tuo indirizzo e-mail e la password (che hai creato al momento dell\'ordine).';

?>

==> prestashop_1.5.2.0.zip: prestashop/translations/it/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF01a2436b8e3782c1f99e6b26adf901b2'] = 'Valore tassa';
$_LANGPDF['PDF023f66b09075fa1cc29e74bed9f5ac40'] = 'Dettaglio tasse';
$_LANGPDF['PDF03ab340b3f99e03cff9e84314ead38c0'] = 'Qtà';
$_LANGPDF['PDF065ab3a28ca4f16f55f103adc7d0226f'] = 'Consegna';
$_LANGPDF['PDF068f80c7519d0528fb08e82137a72131'] = 'Prodotti';
$_LANGPDF['PDF078ac079d154d21533c57bced9fcb10f'] = '(tasse escl.):';
$_LANGPDF['PDF09466661df2abefeecf849e52fce8fb4'] = 'Totale';
$_LANGPDF['PDF0d8d58008ef5dd7afce337373ef73993'] = 'Data';
$_LANGPDF['PDF104d9898c04874d0fbac36e125fa1369'] = 'Sconto';
$_LANGPDF['PDF1300f86974cafc2d65eb1f082a26bdf1'] = 'Riepilogo';
$_LANGPDF['PDF197101c4a1b1fc503dcd6ebee127aa10'] = 'PU';
$_LANGPDF['PDF19abe6c02a26dcd93020396df8d0721c'] = 'Totale sconti:';
$_LANGPDF['PDF1a22913fb1b16ada25c2637af9d44013'] = 'Prodotto / Riferimento';
$_LANGPDF['PDF1d744a9ad1dac20645cfc4a36b77323b'] = 'immagine (s)';
$_LANGPDF['PDF20a34c4e30c5bbe1d3f870ac55f0d831'] = 'Aliquota tassa';
$_LANGPDF['PDF22caf639b05c0fa192e81d58c553c89a'] = 'Totale tasse escluse';
$_LANGPDF['PDF28a59051cd90053f87bacd5f1ffbc0b8'] = 'Indirizzo di fatturazione';
$_LANGPDF['PDF29103375229a5c363403ec4afb5c3e8f'] = '(tasse incl.)';
$_LANGPDF['PDF2b56b5ec383be252fe778c4c6066b2fb'] = 'Indirizzo di fatturazione e spedizione';
$_LANGPDF['PDF2f2f0f119a907c6c67a3c6fcde0193ab'] = 'Indirizzo di consegna:';
$_LANGPDF['PDF2fc3a7b3466e28c082f9957b5df63066'] = 'Importo dovuto rimanente';
$_LANGPDF['PDF34bfda153cbe51eef5d4a88cdd7b616d'] = 'Stampa questo documento ed inseriscilo nel pacco da restituire.';
$_LANGPDF['PDF3601146c4e948c32b6424d2c0a7f0118'] = 'Prezzo';
$_LANGPDF['PDF3796bba38e4bc7dbc3ec97d73be42328'] = 'Se le seguenti condizioni non sono rispettate ci riserviamo il diritto di rifiutare il pacchetto e / o rimborso:';
$_LANGPDF['PDF3a6a6d37bea2c7567f8599ea88b47930'] = 'Totale Tasse Escluse';
$_LANGPDF['PDF3a80d6ec5285dd5d3930db30d04e2b9e'] = 'SE: Sconto escluso';
$_LANGPDF['PDF448634536559b1f8aaa975e0aa12b930'] = 'TOTALE DA PAGARE';
$_LANGPDF['PDF5082245495aa792b3d0874088d2b111b'] = 'Totale prodotto';
$_LANGPDF['PDF59aac4eb50a8249cbc9c12240c6a0a14'] = 'Per ulteriore assistenza contatta il nostro servizio clienti:';
$_LANGPDF['PDF5e5f0a863cd129317037e3def37b4097'] = 'Azienda:';
$_LANGPDF['PDF627be65d466c88030f7afcfdaf6d794f'] = '(Sconto escluso)';
$_LANGPDF['PDF63d5049791d9d79d86e9a108b0a999ca'] = 'Riferimento';
$_LANGPDF['PDF66f6e4bbd0a0af1af6b54763871dd280'] = 'Prodotti ordinati:';
$_LANGPDF['PDF6703aa9936582b4381418f7d523370b4'] = 'Aliquota sconto';
$_LANGPDF['PDF67606e3dd25c5effeb991c704b96d19c'] = 'Tutti I prodotti devono essere restituiti nel loro imballo originale senza danni o usura';
$_LANGPDF['PDF699e6bd4690ed3bd5f658052e12aba04'] = 'Valore tassa';
$_LANGPDF['PDF6b9e9f2472786ed1e76005bfc37bc8af'] = 'Sconto ordine';
$_LANGPDF['PDF6c2fbe34c186a6b5725d212ad8cd2432'] = 'Fatture';
$_LANGPDF['PDF6f3455d187a23443796efdcbe044096b'] = 'Nessuna tassa';
$_LANGPDF['PDF7137a85d9b8d9e6d09f47767d2ca31ee'] = 'APE';
$_LANGPDF['PDF716be2c7de31f063369ca297a9928403'] = 'Tasse';
$_LANGPDF['PDF7521172dd37ba56442ea866ac18eb49d'] = 'Prima dello sconto';
$_LANGPDF['PDF752ab8bad7c2e2d894ffa7f2b4f59919'] = 'Numero reso:';
$_LANGPDF['PDF77c48b105700c87484e3008ca52a8e57'] = '(Sconto non incluso)';
$_LANGPDF['PDF7926243ab60a08b15932021bf108c578'] = 'Totale prodotto (Tasse escl.)';
$_LANGPDF['PDF840490015637295a7dfe641a8c66a86f'] = 'Quando riceveremo il tuo pacco, sarai informato per email. Inizieremo allora il rimborso del totale del tuo ordine. Facci sapere se hai qualsiasi domanda. ';
$_LANGPDF['PDF88be9ea838e21273267409d76af3b284'] = 'Abbiamo registrato la vostra richiesta di restituzione.';
$_LANGPDF['PDF8a5a12ba783d8cbb761974430d0a4d6a'] = 'Data ordine:';
$_LANGPDF['PDF8fe77c2601e54f1aaef28cfde997bbad'] = 'Aliquota tasse';
$_LANGPDF['PDF96b0141273eabab320119c467cdcaf17'] = 'Totale';
$_LANGPDF['PDF984a93f9899bf0b0a250ba66f022c630'] = 'Totale prodotto (Tasse incl.)';
$_LANGPDF['PDF9a40e5f45fab9e73d0bc7dad94f6caa3'] = 'Ordine di ritorno';
$_LANGPDF['PDF9e023503a19456d31f0760015d035e36'] = 'Ricorda di inserire questo numero di riferimento reso nel pacco da rendere';
$_LANGPDF['PDFa58b1c9575ab07c5be819243c96d9c0e'] = 'SI: Sconto incluso';
$_LANGPDF['PDFa5e35abc0c9e2d2784d0ef619b36448b'] = 'Costi di spedizione';
$_LANGPDF['PDFa61109b693023aed557445989c517982'] = 'Dopo lo sconto';
$_LANGPDF['PDFabd7ef0bbbdeed3a98c962ba07747ca8'] = 'PRODOTTI DA RENDERE';
$_LANGPDF['PDFb602e0d0c6a72053d0a5be60cb2f8126'] = 'Totale tasse:';
$_LANGPDF['PDFc7711fbc0d8f010e06a306cc63ef5393'] = 'Il pacco deve essere restituito al seguente indirizzo:';
$_LANGPDF['PDFc7d76074f459eaa296d3eb71efc23eba'] = 'Rimborso #';
$_LANGPDF['PDFc8ba77264f6e923f5ee35abf3108ae7c'] = 'Prezzo unitario Tasse Escluse';
$_LANGPDF['PDFced2da7b2baf942c0ffd4b8e45ec0fad'] = 'Costo spedizione';
$_LANGPDF['PDFd04e2c1b67f3ef0d475409516b812e8b'] = 'SIRET';
$_LANGPDF['PDFd36a6948b01d3a75ed99858e2bfea939'] = 'Metodo di pagamento:';
$_LANGPDF['PDFd8b2145d049378e78bd41e65b31213f0'] = 'Numero ordine:';
$_LANGPDF['PDFdcd320d017d7f3c317bc8b234287bc9f'] = 'riferimento';
$_LANGPDF['PDFdd0b8feb4eb6c389c284518f5683017c'] = 'Il tuo pacchetto deve essere restituito entro';
$_LANGPDF['PDFe2f324b87eac820c81e4d4a1105dcddf'] = 'Indirizzo di fatturazione e spedizione';
$_LANGPDF['PDFe36ba4b339b83cbb3c807bd0eb5610bc'] = 'Qtà';
$_LANGPDF['PDFe40007b408ac5f66d2c2e6c54f787c99'] = 'Nessun pagamento';
$_LANGPDF['PDFe7bbf027179f23c92bec649fa6ae78e4'] = 'Esente IVA a seconda della sezione 259B del codice generale delle imposte.';
$_LANGPDF['PDFe92cfa244b5eb9025d07522080468445'] = 'Eco- tassa';
$_LANGPDF['PDFea62a2e28a800c367509773730120a67'] = 'giorni dal ricevimento dell\'ordine.';
$_LANGPDF['PDFea9cf7e47ff33b2be14e6dd07cbcefc6'] = 'Spedizione';
$_LANGPDF['PDFf107f5a9ee4ecea58d0f29ae7959baa8'] = 'Designazione';
$_LANGPDF['PDFf4a232c48df10124ee867767a4e7280e'] = 'Base Tasse Escluse';
$_LANGPDF['PDFf6244b08d5e0715572f9d4631b425eae'] = 'ARTICOLI DA SPEDIRE';
$_LANGPDF['PDFf771e4a4df40bf061607fdb8e3f140dc'] = 'Modulo ordine fornitura';
$_LANGPDF['PDFfa2ce544158555e8f06c69dd9e681832'] = 'Totale Tasse Incluse';
$_LANGPDF['PDFff5db4935fb0fbf583796b50f05e25bc'] = 'Una versione elettronica di questa fattura è disponibile nel tuo account. Per accedervi, accedere al nostro sito utilizzando il tuo indirizzo e-mail e la password (che hai creato al momento dell\'ordine).';

?>
